@@ -14,12 +14,14 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from django.core import urlresolvers
 from django import shortcuts
 from django.template.defaultfilters import title  # noqa
+from django import urls
 from django.utils.translation import ugettext_lazy as _
 from django.utils.translation import ungettext_lazy
 
+import six
+
 from horizon import messages
 from horizon import tables
 from horizon.templatetags import sizeformat
@@ -109,7 +111,7 @@ class ResetPassword(tables.LinkAction):
 
     def get_link_url(self, datum):
         cluster_id = self.table.get_object_id(datum)
-        return urlresolvers.reverse(self.url, args=[cluster_id])
+        return urls.reverse(self.url, args=[cluster_id])
 
 
 class UpdateRow(tables.Row):
@@ -207,6 +209,12 @@ def get_host(instance):
     return _("Not Assigned")
 
 
+def get_instance_volume_size(instance):
+    if hasattr(instance, "volume"):
+        return sizeformat.diskgbformat(instance.volume.get("size"))
+    return _("Not available")
+
+
 class InstancesTable(tables.DataTable):
     name = tables.Column("name",
                          verbose_name=_("Name"))
@@ -217,6 +225,9 @@ class InstancesTable(tables.DataTable):
     size = tables.Column(get_instance_size,
                          verbose_name=_("Size"),
                          attrs={'data-type': 'size'})
+    volume_size = tables.Column(get_instance_volume_size,
+                                verbose_name=_("Volume Size"),
+                                attrs={'data-type': 'size'})
     status = tables.Column("status",
                            filters=(title, filters.replace_underscores),
                            verbose_name=_("Status"))
@@ -269,10 +280,10 @@ class ClusterShrinkAction(tables.BatchAction):
         except Exception as ex:
             LOG.error('Action %(action)s failed with %(ex)s for %(data)s' %
                       {'action': self._get_action_name(past=True).lower(),
-                       'ex': ex.message,
+                       'ex': six.text_type(ex),
                        'data': display_str})
             msg = _('Unable to remove instances from cluster: %s')
-            messages.error(request, msg % ex.message)
+            messages.error(request, msg % six.text_type(ex))
 
         return shortcuts.redirect(self.get_success_url(request))
 
@@ -298,7 +309,7 @@ class ClusterGrowAddInstance(tables.LinkAction):
     classes = ("ajax-modal",)
 
     def get_link_url(self):
-        return urlresolvers.reverse(
+        return urls.reverse(
             self.url, args=[self.table.kwargs['cluster_id']])
 
 
@@ -404,14 +415,14 @@ class ClusterGrowAction(tables.Action):
             messages.success(request, msg)
         except Exception as ex:
             LOG.error('Action grow cluster failed with %(ex)s for %(data)s' %
-                      {'ex': ex.message,
+                      {'ex': six.text_type(ex),
                        'data': display_str})
             msg = _('Unable to grow cluster: %s')
-            messages.error(request, msg % ex.message)
+            messages.error(request, msg % six.text_type(ex))
         finally:
             cluster_manager.delete(cluster_id)
 
-        return shortcuts.redirect(urlresolvers.reverse(
+        return shortcuts.redirect(urls.reverse(
             "horizon:project:database_clusters:index"))
 
 
